@@ -157,17 +157,10 @@ class TestFeature(unittest.TestCase):
 
         p = om.Problem()
 
-        ivc = om.IndepVarComp()
-        ivc.add_output(name='pos_ecef', shape=(m, 3), units='km')
+        demux_comp = p.model.add_subsystem(name='demux', subsys=om.DemuxComp(vec_size=n),
+                                         promotes_inputs=['pos_ecef'])
 
-        p.model.add_subsystem(name='ivc',
-                              subsys=ivc,
-                              promotes_outputs=['pos_ecef'])
-
-        mux_comp = p.model.add_subsystem(name='demux',
-                                         subsys=om.DemuxComp(vec_size=n))
-
-        mux_comp.add_var('pos', shape=(m, n), axis=1, units='km')
+        demux_comp.add_var('pos_ecef', shape=(m, n), axis=1, units='km')
 
         p.model.add_subsystem(name='longitude_comp',
                               subsys=om.ExecComp('long = atan(y/x)',
@@ -175,19 +168,18 @@ class TestFeature(unittest.TestCase):
                                                  y={'value': np.ones(m), 'units': 'km'},
                                                  long={'value': np.ones(m), 'units': 'rad'}))
 
-        p.model.connect('demux.pos_0', 'longitude_comp.x')
-        p.model.connect('demux.pos_1', 'longitude_comp.y')
-        p.model.connect('pos_ecef', 'demux.pos')
+        p.model.connect('demux.pos_ecef_0', 'longitude_comp.x')
+        p.model.connect('demux.pos_ecef_1', 'longitude_comp.y')
 
         p.setup()
 
-        p['pos_ecef'][:, 0] = 6378 * np.cos(np.linspace(0, 2*np.pi, m))
-        p['pos_ecef'][:, 1] = 6378 * np.sin(np.linspace(0, 2*np.pi, m))
-        p['pos_ecef'][:, 2] = 0.0
+        p.set_val('pos_ecef', 6378 * np.cos(np.linspace(0, 2*np.pi, m)), indices=om.slicer[:, 0])
+        p.set_val('pos_ecef', 6378 * np.sin(np.linspace(0, 2*np.pi, m)), indices=om.slicer[:, 1])
+        p.set_val('pos_ecef', 0.0, indices=om.slicer[:, 2])
 
         p.run_model()
 
-        expected = np.arctan(p['pos_ecef'][:, 1] / p['pos_ecef'][:, 0])
+        expected = np.arctan(p.get_val('pos_ecef', indices=om.slicer[:, 1]) / p.get_val('pos_ecef', indices=om.slicer[:, 0]))
         assert_near_equal(p.get_val('longitude_comp.long'), expected)
 
 
